# eric7.Plugins.VcsPlugins.vcsPySvn.SvnChangeListsDialog

Module implementing a dialog to browse the change lists.

### Global Attributes

None

### Classes

SvnChangeListsDialog | Class implementing a dialog to browse the change lists.

### Functions

None

## SvnChangeListsDialog

Class implementing a dialog to browse the change lists.

### Derived from

QDialog, SvnDialogMixin, Ui_SvnChangeListsDialog

### Class Attributes

None

### Class Methods

None

### Methods

SvnChangeListsDialog | Constructor
__finish | Private slot called when the user pressed the button.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
on_changeLists_currentItemChanged | Private slot to handle the selection of a new item.
start | Public slot to populate the data.

### Static Methods

None

#### SvnChangeListsDialog (Constructor)

SvnChangeListsDialog(vcs, parent=None)

Constructor

vcs (Subversion)
  reference to the vcs object
parent (QWidget)
  parent widget

#### SvnChangeListsDialog.__finish

__finish()

Private slot called when the user pressed the button.

#### SvnChangeListsDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button (QAbstractButton)
  button that was clicked

#### SvnChangeListsDialog.on_changeLists_currentItemChanged

on_changeLists_currentItemChanged(current, _previous)

Private slot to handle the selection of a new item.

current (QListWidgetItem)
  current item
_previous (QListWidgetItem)
  previous current item (unused)

#### SvnChangeListsDialog.start

start(path)

Public slot to populate the data.

path (str)
  directory name to show change lists for

Up